@@ -2,19 +2,27 @@
 (*                                                                     *)
 (*                               Ledit                                 *)
 (*                                                                     *)
-(*       Daniel de Rauglaudre, projet Cristal, INRIA Rocquencourt      *)
+(*                Daniel de Rauglaudre, INRIA Rocquencourt             *)
 (*                                                                     *)
-(*  Copyright 1997 Institut National de Recherche en Informatique et   *)
-(*  Automatique.  Distributed only by permission.                      *)
+(*  Copyright 1997-2007 Institut National de Recherche en Informatique *)
+(*  et Automatique.  Distributed only by permission.                   *)
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: ledit.mli,v 1.3 1997/10/28 10:01:04 ddr Exp $ *)
+(* $Id: ledit.mli,v 1.10 2007/03/20 13:55:06 deraugla Exp $ *)
+
+type a_char = 'abstract;
+
+value input_char : in_channel -> a_char;
+value print_a_char : a_char -> unit;
 
-value input_char : in_channel -> char;
 value set_prompt : string -> unit;
 value get_prompt : unit -> string;
 value open_histfile : bool -> string -> unit;
 value close_histfile : unit -> unit;
 value set_max_len : int -> unit;
-value set_son : int -> unit;
+value set_son_pid : int -> unit;
+
+value unset_meta_as_escape : unit -> unit;
+value set_utf8 : unit -> unit;
+value set_ascii : unit -> unit;
